gap_jupyter: Jupyter kernel for GAP
===================================

Description
-----------

Jupyter kernel for GAP

This wrapper-kernel is a Jupyter kernel for the GAP Computer Algebra
System based on the same ideas as the bash wrapper kernel.

License
-------

3-Clause BSD License


Upstream Contact
----------------

-  https://github.com/gap-packages/jupyter-gap
